// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2012             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <sys/stat.h>
#include <strings.h>
#include <map>
#include <set>

#include "nagios.h"
#include "store.h"
#include "Store.h"
#include "Query.h"
#include "InputBuffer.h"
#include "OutputBuffer.h"
#include "logger.h"
#include "TimeperiodsCache.h"

using namespace std;

Store *g_store = 0;
TimeperiodsCache *g_timeperiods_cache = 0;

/* API functions for event broker module (with C linkage) */

void store_init()
{
    g_store = new Store();
    g_timeperiods_cache = new TimeperiodsCache();
}


void store_deinit()
{
    if (g_store) {
        delete g_store;
        g_store = 0;
    }
    if (g_timeperiods_cache) {
        delete g_timeperiods_cache;
        g_timeperiods_cache = 0;
    }
}

void store_register_comment(nebstruct_comment_data *d)
{
    g_store->registerComment(d);
}

void store_register_downtime(nebstruct_downtime_data *d)
{
    g_store->registerDowntime(d);
}

int store_answer_request(void *ib, void *ob, int fd)
{
    return g_store->answerRequest((InputBuffer *)ib, (OutputBuffer *)ob, fd);
}

void *create_outputbuffer(int *termination_flag)
{
    return new OutputBuffer(termination_flag);
}

void flush_output_buffer(void *ob, int fd)
{
    ((OutputBuffer *)ob)->flush(fd);
}

void delete_outputbuffer(void *ob)
{
    delete (OutputBuffer *)ob;
}

void *create_inputbuffer(int *termination_flag)
{
    return new InputBuffer(termination_flag);
}

void set_inputbuffer_fd(void *ib, int fd)
{
    ((InputBuffer *)ib)->setFd(fd);
}

void delete_inputbuffer(void *ib)
{
    delete (InputBuffer *)ib;
}

void update_timeperiods_cache(time_t now)
{
    g_timeperiods_cache->update(now);
}
